@@ -173,7 +173,10 @@ Liveman::Cpanfile - Perl project dependency analyzer
 
 	use Liveman::Cpanfile;
 	
-	my $result = << 'END';
+	chmod 0755, $_ for qw!script/test_script bin/tool!;
+	
+	$::cpanfile = Liveman::Cpanfile->new;
+	$::cpanfile->cpanfile # -> << 'END'
 	requires 'perl', '5.22.0';
 	
 	on 'develop' => sub {
@@ -211,11 +214,6 @@ Liveman::Cpanfile - Perl project dependency analyzer
 	requires 'strict';
 	requires 'warnings';
 	END
-	
-	chmod 0755, $_ for qw!script/test_script bin/tool!;
-	
-	$::cpanfile = Liveman::Cpanfile->new;
-	$::cpanfile->cpanfile # -> $result
 
 =head1 DESCRIPTION
 
